pub struct ParticleSettings {Show 18 fields
pub lifetime: RandF32,
pub scale_curve: FireworkCurve<f32>,
pub initial_scale: RandF32,
pub acceleration: Vec3,
pub angular_acceleration: Vec3,
pub linear_drag: f32,
pub angular_drag: f32,
pub base_color: FireworkGradient<LinearRgba>,
pub base_color_texture: Option<Handle<Image>>,
pub emissive_color: FireworkGradient<LinearRgba>,
pub normal_map_texture: Option<Handle<Image>>,
pub orm_texture: Option<Handle<Image>>,
pub fade_edge: f32,
pub fade_scene: f32,
pub blend_mode: BlendMode,
pub pbr: bool,
pub collision_settings: Option<ParticleCollisionSettings>,
pub event_handlers: ParticleEventHandlers,
}Fields
lifetime: RandF32Lifetime of a particle
scale_curve: FireworkCurve<f32>Evolution of scale over time, applied as a factor to initial scale. The curve should have domain [0,1]
initial_scale: RandF32Initial scale of particles
acceleration: Vec3Linear acceleration of particles
angular_acceleration: Vec3Angular acceleration of particles
linear_drag: f32Drag applied as a linear coefficient of velocity
angular_drag: f32Angular drag applied as a linear coefficient of angular velocity
base_color: FireworkGradient<LinearRgba>Color over lifetime. If a texture is specified the final color will be multiplied.
base_color_texture: Option<Handle<Image>>emissive_color: FireworkGradient<LinearRgba>Emissive color over lifetime. If a texture is specified the final color will be multiplied.
normal_map_texture: Option<Handle<Image>>orm_texture: Option<Handle<Image>>Occlusion/Roughness/Metallic texture; that is, a texture where the red, green and blue channels represent the material’s occlusion, perceptual roughness and “metallic” setting, respectively. The occlusion value is currently ignored.
fade_edge: f32Round out the particle with fading at the edges. If 0, no fading is applied. The value should be between 0 and 1.
fade_scene: f32Fade out at the intersections between particles and the scene to avoid sharp edges. The larger the value, the longer the fade range.
blend_mode: BlendModeAlpha blend mode for the particles
pbr: boolWhether to use the PBR pipeline for the particle
collision_settings: Option<ParticleCollisionSettings>If Some, particles will collide with the scene according to the provided parameters If None, no particle collision will occur.
event_handlers: ParticleEventHandlersTrait Implementations
Sourceimpl Clone for ParticleSettings
impl Clone for ParticleSettings
Sourcefn clone(&self) -> ParticleSettings
fn clone(&self) -> ParticleSettings
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ParticleSettings
impl Debug for ParticleSettings
Sourceimpl Default for ParticleSettings
impl Default for ParticleSettings
Sourceimpl FromReflect for ParticleSettings
impl FromReflect for ParticleSettings
Sourcefn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
fn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for ParticleSettings
impl GetTypeRegistration for ParticleSettings
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Sourceimpl PartialReflect for ParticleSettings
impl PartialReflect for ParticleSettings
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
fn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Sourcefn reflect_owned(self: Box<Self>) -> ReflectOwned
fn reflect_owned(self: Box<Self>) -> ReflectOwned
Sourcefn try_into_reflect(
self: Box<Self>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<Self>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Sourcefn try_as_reflect(&self) -> Option<&dyn Reflect>
fn try_as_reflect(&self) -> Option<&dyn Reflect>
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
fn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
Sourcefn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
Sourcefn as_partial_reflect(&self) -> &dyn PartialReflect
fn as_partial_reflect(&self) -> &dyn PartialReflect
Sourcefn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
fn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
Sourcefn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
fn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Self using reflection. Read moreSourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Sourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails. Read moreSourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Sourceimpl Reflect for ParticleSettings
impl Reflect for ParticleSettings
Sourcefn as_any_mut(&mut self) -> &mut dyn Any
fn as_any_mut(&mut self) -> &mut dyn Any
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
fn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
Sourcefn as_reflect(&self) -> &dyn Reflect
fn as_reflect(&self) -> &dyn Reflect
Sourcefn as_reflect_mut(&mut self) -> &mut dyn Reflect
fn as_reflect_mut(&mut self) -> &mut dyn Reflect
Sourceimpl Struct for ParticleSettings
impl Struct for ParticleSettings
Sourcefn field(&self, name: &str) -> Option<&dyn PartialReflect>
fn field(&self, name: &str) -> Option<&dyn PartialReflect>
name as a &dyn PartialReflect.Sourcefn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
fn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
name as a
&mut dyn PartialReflect.Sourcefn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
fn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
index as a
&dyn PartialReflect.Sourcefn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
fn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
index
as a &mut dyn PartialReflect.Sourcefn name_at(&self, index: usize) -> Option<&str>
fn name_at(&self, index: usize) -> Option<&str>
index.Sourcefn iter_fields(&self) -> FieldIter<'_>
fn iter_fields(&self) -> FieldIter<'_>
Sourcefn to_dynamic_struct(&self) -> DynamicStruct
fn to_dynamic_struct(&self) -> DynamicStruct
DynamicStruct from this struct.Sourcefn get_represented_struct_info(&self) -> Option<&'static StructInfo>
fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
None if TypeInfo is not available.Sourceimpl TypePath for ParticleSettings
impl TypePath for ParticleSettings
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>